@@ -503,7 +503,7 @@ def AddWiFiConnection(self, dev_path, connection_name, ssid_name, _key_mgmt):
 
     The SSID must match one of the previously created access points.
 
-    Please note that this does not set any global properties.
+    Please note that this only sets minimal global properties in ipv{4,6}, no others.
 
     Returns the new object path.
     """
@@ -558,6 +558,12 @@ def AddWiFiConnection(self, dev_path, connection_name, ssid_name, _key_mgmt):
             "id": ssid_name,
             "uuid": str(uuid.uuid4()),
         },
+        "ipv4": {
+            "method": "auto",
+        },
+        "ipv6": {
+            "method": "auto",
+        },
     }
 
     if security != NM80211ApSecurityFlags.NM_802_11_AP_SEC_NONE:
@@ -810,7 +816,7 @@ def SettingsGetConnectionByUuid(self, conn_uuid):
         settings = self.conn.GetSettings()
         if settings["connection"]["uuid"] == conn_uuid:
             return o
-    raise dbus.exceptions.DBusException(f"There was no connection with uuid {conn_uuid}")
+    raise dbus.exceptions.DBusException("No connection with the UUID was found.")
 
 
 def ConnectionUpdate(self, settings):
